@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -25,7 +25,7 @@ public:
     void setOrder(int order);
     Q_REQUIRED_RESULT int order() const;
 
-    virtual Q_REQUIRED_RESULT bool canProcessKeyEvent() const;
+    Q_REQUIRED_RESULT virtual bool canProcessKeyEvent() const;
 
 private:
     std::unique_ptr<PluginEditorPrivate> const d;
