@@ -106,7 +106,7 @@ void RecipientsPicker::updateLabel(int nbSelected)
 
 void RecipientsPicker::slotSelectionChanged()
 {
-    const int selectedItems{mView->emailAddressSelectionWidget()->selectedAddresses().count()};
+    const auto selectedItems{mView->emailAddressSelectionWidget()->selectedAddresses().count()};
     const bool hasSelection = (selectedItems != 0);
     mUser1Button->setEnabled(hasSelection);
     mUser2Button->setEnabled(hasSelection);
@@ -166,7 +166,7 @@ void RecipientsPicker::pick(Recipient::Type type)
     }
 
     if (count > MessageComposerSettings::self()->maximumRecipients()) {
-        KMessageBox::sorry(this,
+        KMessageBox::error(this,
                            i18np("You selected 1 recipient. The maximum supported number of "
                                  "recipients is %2.\nPlease adapt the selection.",
                                  "You selected %1 recipients. The maximum supported number of "
@@ -184,7 +184,7 @@ void RecipientsPicker::pick(Recipient::Type type)
 
         Q_EMIT pickedRecipient(recipient, tooManyAddress);
         if (tooManyAddress) {
-            KMessageBox::sorry(this, i18n("You can not add more recipients."));
+            KMessageBox::error(this, i18n("You can not add more recipients."));
             break;
         }
     }
