@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -8,9 +8,9 @@
 #include "sendlaterinterface.h"
 #include "sendlaterutil_p.h"
 
-#include <AkonadiCore/ServerManager>
+#include <Akonadi/ServerManager>
 
-#include <servermanager.h>
+#include <Akonadi/ServerManager>
 
 using namespace MessageComposer;
 
