@@ -1,15 +1,15 @@
 /*
-  SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
 */
 
-#ifndef SCAMCHECKSHORTURLMANAGER_H
-#define SCAMCHECKSHORTURLMANAGER_H
+#pragma once
 
 #include "messageviewer_export.h"
 #include <QObject>
+#include <memory>
 namespace MessageViewer
 {
 class ScamCheckShortUrl;
@@ -28,7 +28,6 @@ public:
     Q_REQUIRED_RESULT ScamCheckShortUrl *scamCheckShortUrl() const;
 
 private:
-    ScamCheckShortUrlManagerPrivate *const d;
+    std::unique_ptr<ScamCheckShortUrlManagerPrivate> const d;
 };
 }
-#endif // SCAMCHECKSHORTURLMANAGER_H
