@@ -4,8 +4,7 @@
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MESSAGEVIEWER_URLHANDLERMANAGER_P_H
-#define MESSAGEVIEWER_URLHANDLERMANAGER_P_H
+#pragma once
 
 #include "urlhandlermanager.h"
 #include <MessageViewer/URLHandler>
@@ -38,7 +37,7 @@ public:
 private:
     Q_REQUIRED_RESULT QVector<const Interface::BodyPartURLHandler *> handlersForPart(KMime::Content *node) const;
 
-    typedef QHash<QByteArray, QVector<const Interface::BodyPartURLHandler *>> BodyPartHandlerList;
+    using BodyPartHandlerList = QHash<QByteArray, QVector<const Interface::BodyPartURLHandler *>>;
     BodyPartHandlerList mHandlers;
 };
 
@@ -50,9 +49,7 @@ public:
     {
     }
 
-    ~KMailProtocolURLHandler() override
-    {
-    }
+    ~KMailProtocolURLHandler() override = default;
 
     Q_REQUIRED_RESULT bool handleClick(const QUrl &, ViewerPrivate *) const override;
     Q_REQUIRED_RESULT bool handleContextMenuRequest(const QUrl &url, const QPoint &, ViewerPrivate *) const override
@@ -71,9 +68,7 @@ public:
     {
     }
 
-    ~ExpandCollapseQuoteURLManager() override
-    {
-    }
+    ~ExpandCollapseQuoteURLManager() override = default;
 
     Q_REQUIRED_RESULT bool handleClick(const QUrl &, ViewerPrivate *) const override;
     Q_REQUIRED_RESULT bool handleDrag(const QUrl &url, ViewerPrivate *window) const override;
@@ -93,9 +88,7 @@ public:
     {
     }
 
-    ~SMimeURLHandler() override
-    {
-    }
+    ~SMimeURLHandler() override = default;
 
     Q_REQUIRED_RESULT bool handleClick(const QUrl &, ViewerPrivate *) const override;
     Q_REQUIRED_RESULT bool handleContextMenuRequest(const QUrl &, const QPoint &, ViewerPrivate *) const override
@@ -114,9 +107,7 @@ public:
     {
     }
 
-    ~MailToURLHandler() override
-    {
-    }
+    ~MailToURLHandler() override = default;
 
     Q_REQUIRED_RESULT bool handleClick(const QUrl &, ViewerPrivate *) const override
     {
@@ -139,9 +130,7 @@ public:
     {
     }
 
-    ~ContactUidURLHandler() override
-    {
-    }
+    ~ContactUidURLHandler() override = default;
 
     Q_REQUIRED_RESULT bool handleClick(const QUrl &, ViewerPrivate *) const override;
     Q_REQUIRED_RESULT bool handleContextMenuRequest(const QUrl &url, const QPoint &p, ViewerPrivate *) const override;
@@ -156,9 +145,7 @@ public:
     {
     }
 
-    ~HtmlAnchorHandler() override
-    {
-    }
+    ~HtmlAnchorHandler() override = default;
 
     Q_REQUIRED_RESULT bool handleClick(const QUrl &, ViewerPrivate *) const override;
     Q_REQUIRED_RESULT bool handleContextMenuRequest(const QUrl &, const QPoint &, ViewerPrivate *) const override
@@ -168,7 +155,7 @@ public:
 
     Q_REQUIRED_RESULT QString statusBarMessage(const QUrl &, ViewerPrivate *) const override
     {
-        return QString();
+        return {};
     }
 };
 
@@ -180,9 +167,7 @@ public:
     {
     }
 
-    ~AttachmentURLHandler() override
-    {
-    }
+    ~AttachmentURLHandler() override = default;
 
     Q_REQUIRED_RESULT bool handleClick(const QUrl &, ViewerPrivate *) const override;
     Q_REQUIRED_RESULT bool handleShiftClick(const QUrl &, ViewerPrivate *window) const override;
@@ -204,9 +189,7 @@ public:
     {
     }
 
-    ~ShowAuditLogURLHandler() override
-    {
-    }
+    ~ShowAuditLogURLHandler() override = default;
 
     Q_REQUIRED_RESULT bool handleClick(const QUrl &, ViewerPrivate *) const override;
     Q_REQUIRED_RESULT bool handleContextMenuRequest(const QUrl &, const QPoint &, ViewerPrivate *) const override;
@@ -224,9 +207,7 @@ public:
     {
     }
 
-    ~InternalImageURLHandler() override
-    {
-    }
+    ~InternalImageURLHandler() override = default;
 
     Q_REQUIRED_RESULT bool handleDrag(const QUrl &url, ViewerPrivate *window) const override;
     Q_REQUIRED_RESULT bool willHandleDrag(const QUrl &url, ViewerPrivate *window) const override;
@@ -242,7 +223,7 @@ public:
 
     Q_REQUIRED_RESULT QString statusBarMessage(const QUrl &, ViewerPrivate *) const override
     {
-        return QString();
+        return {};
     }
 };
 
@@ -254,9 +235,7 @@ public:
     {
     }
 
-    ~EmbeddedImageURLHandler() override
-    {
-    }
+    ~EmbeddedImageURLHandler() override = default;
 
     Q_REQUIRED_RESULT bool handleDrag(const QUrl &url, ViewerPrivate *window) const override;
     Q_REQUIRED_RESULT bool willHandleDrag(const QUrl &url, ViewerPrivate *window) const override;
@@ -273,7 +252,7 @@ public:
     Q_REQUIRED_RESULT QString statusBarMessage(const QUrl &url, ViewerPrivate *) const override
     {
         Q_UNUSED(url)
-        return QString();
+        return {};
     }
 };
 
@@ -285,9 +264,7 @@ public:
     {
     }
 
-    ~KRunURLHandler() override
-    {
-    }
+    ~KRunURLHandler() override = default;
 
     Q_REQUIRED_RESULT bool handleClick(const QUrl &, ViewerPrivate *) const override;
     Q_REQUIRED_RESULT bool handleContextMenuRequest(const QUrl &, const QPoint &, ViewerPrivate *) const override
@@ -297,8 +274,7 @@ public:
 
     Q_REQUIRED_RESULT QString statusBarMessage(const QUrl &, ViewerPrivate *) const override
     {
-        return QString();
+        return {};
     }
 };
 }
-#endif // MESSAGEVIEWER_URLHANDLERMANAGER_P_H
