@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -14,9 +14,7 @@ WebEngineExportHtmlPageJobTest::WebEngineExportHtmlPageJobTest(QObject *parent)
 {
 }
 
-WebEngineExportHtmlPageJobTest::~WebEngineExportHtmlPageJobTest()
-{
-}
+WebEngineExportHtmlPageJobTest::~WebEngineExportHtmlPageJobTest() = default;
 
 void WebEngineExportHtmlPageJobTest::shouldHaveDefaultValue()
 {
