@@ -1,14 +1,14 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef MAILWEBENGINEACCESSKEY_H
-#define MAILWEBENGINEACCESSKEY_H
+#pragma once
 
 #include "webengineviewer_export.h"
 #include <QObject>
+#include <memory>
 
 class KActionCollection;
 class QWheelEvent;
@@ -37,18 +37,15 @@ public:
     void keyReleaseEvent(QKeyEvent *e);
 
     void showAccessKeys();
+    void hideAccessKeys();
 
 Q_SIGNALS:
     void openUrl(const QUrl &url);
-public Q_SLOTS:
-    void hideAccessKeys();
 
 private Q_SLOTS:
     void handleSearchAccessKey(const QVariant &res);
 
 private:
-    WebEngineAccessKeyPrivate *const d;
+    std::unique_ptr<WebEngineAccessKeyPrivate> const d;
 };
 }
-
-#endif
